#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-websockets
version:              3.0.1.2
visibility:           public
id:                   wai-websockets-3.0.1.2-B03isnXIgJ7D9mH5ykcb4r
key:                  wai-websockets-3.0.1.2-B03isnXIgJ7D9mH5ykcb4r
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.

category:             Web, Yesod
abi:                  c3204e1d85ca680ffcb798c0675d0ed0
exposed:              True
exposed-modules:      Network.Wai.Handler.WebSockets
import-dirs:          /usr/lib/ghc-8.10.5/site-local/wai-websockets-3.0.1.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/wai-websockets-3.0.1.2
hs-libraries:         HSwai-websockets-3.0.1.2-B03isnXIgJ7D9mH5ykcb4r
depends:
    base-4.14.2.0 bytestring-0.10.12.0
    case-insensitive-1.2.1.0-G5jOpOHgp1lAnadtJPMHHB
    http-types-0.12.3-JSCBEGU6f6MIPS3hXwEPIB
    network-3.1.2.2-5EE9GqQpTmvH0oBl8byO4M transformers-0.5.6.2
    wai-3.2.3-6NrdunSiuKK6vnccK2cwty
    websockets-0.12.7.2-85saducd4mh7JOMIBzytg3

haddock-interfaces:
    /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock

haddock-html:         /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

